{ config, ... }:

{

  services.restic.backups = {
    "gitea" = {
      paths = [ "/var/lib/gitea" ];
      repository = "sftp:restic@despondos.nao.sh:/etheria/backup/wind/gitea";
      initialize = true;
      pruneOpts = [ "--keep-daily 7" "--keep-weekly 5" "--keep-monthly 12" "--keep-yearly 75" ];
      timerConfig = { "OnCalendar" = "02:15"; };
      extraOptions = [ "sftp.command='ssh restic@despondos.nao.sh -i ${config.secrets.files.ssh_key.file} -s sftp'" ];
      passwordFile = builtins.toString config.secrets.files.restic_pass.file;
      user = "gitea";
    };
    "postgres" = {
      paths = [ "/var/lib/postgresql/backup" ];
      repository = "sftp:restic@despondos.nao.sh:/etheria/backup/wind/postgres";
      initialize = true;
      pruneOpts = [ "--keep-daily 7" "--keep-weekly 5" "--keep-monthly 12" "--keep-yearly 75" ];
      timerConfig = { "OnCalendar" = "03:00"; };
      extraOptions = [ "sftp.command='ssh restic@despondos.nao.sh -i ${config.secrets.files.ssh_key.file} -s sftp'" ];
      passwordFile = builtins.toString config.secrets.files.restic_pass.file;
      user = "postgres";
    };
    "synapse" = {
      paths = [ "/var/lib/matrix-synapse" ];
      repository = "sftp:restic@despondos.nao.sh:/etheria/backup/wind/synapse";
      initialize = true;
      pruneOpts = [ "--keep-daily 7" "--keep-weekly 5" "--keep-monthly 12" "--keep-yearly 75" ];
      timerConfig = { "OnCalendar" = "03:30"; };
      extraOptions = [ "sftp.command='ssh restic@despondos.nao.sh -i ${config.secrets.files.ssh_key.file} -s sftp'" ];
      passwordFile = builtins.toString config.secrets.files.restic_pass.file;
      user = "matrix-synapse";
    };
    "vaultwarden" = {
      paths = [ "/var/lib/bitwarden_rs" ];
      repository = "sftp:restic@despondos.nao.sh:/etheria/backup/wind/vaultwarden";
      initialize = true;
      pruneOpts = [ "--keep-daily 7" "--keep-weekly 5" "--keep-monthly 12" "--keep-yearly 75" ];
      timerConfig = { "OnCalendar" = "23:45"; };
      extraOptions = [ "sftp.command='ssh restic@despondos.nao.sh -i ${config.secrets.files.ssh_key.file} -s sftp'" ];
      passwordFile = builtins.toString config.secrets.files.restic_pass.file;
      user = "vaultwarden";
    };
  };
}
